@@ -1,16 +1,17 @@
 import os
 import itertools
+import multiprocessing as mp
 
 from .equity_curves import *
 from .signals import *
 
-def generate_filepath(py_filename, output_folder, start_date, end_date, para_dict, para_values):
+def generate_filepath(py_filename, output_folder, start_date, end_date, para_dict, para_combination):
     start_date_str = datetime.datetime.strptime(start_date, '%Y-%m-%d').strftime("%Y%m%d")
     end_date_str = datetime.datetime.strptime(end_date, '%Y-%m-%d').strftime("%Y%m%d")
     save_name = f'file={py_filename}&date={start_date_str}{end_date_str}'
 
     for i, key in enumerate(para_dict):
-        para = para_values[i]
+        para = para_combination[i]
         if key == 'code':
             if str(para).isdigit():
                 para = str(para).zfill(5)
@@ -35,16 +36,53 @@ def result_df_template(para_dict):
     return df
 
 
-def plot_equity_curves(filename, output_folder, start_date, end_date, para_dict, result_df, settings):
+def mp_cal_performance(tuple_data):
+    save_path    = tuple_data[0]
+    start_date   = tuple_data[1]
+    end_date     = tuple_data[2]
+    manager_list = tuple_data[3]
 
-    app = equity_curves.Plot(filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings)
+    result = cal_performance(save_path, start_date, end_date)
+    manager_list.append(result)
+
+
+def get_result_df(py_filename, output_folder, start_date, end_date, para_dict):
+    result_df = result_df_template(para_dict)
+    manager_list = mp.Manager().list()
+
+    cal_performance_list = []
+    for i in range(len(result_df)):
+        save_path = generate_filepath(py_filename, output_folder, start_date, end_date, para_dict, result_df.iloc[i])
+        cal_performance_list.append((save_path, start_date, end_date, manager_list))
+
+    pool = mp.Pool()
+    pool.map(mp_cal_performance, cal_performance_list)
+    pool.close()
+
+    temp_dict = {}
+    for sub_dict in manager_list:
+        for key, value in sub_dict.items():
+            if key not in temp_dict: temp_dict[key] = []
+            temp_dict[key].append(value)
+
+    for key in temp_dict:
+        result_df[key] = temp_dict[key]
+
+    return result_df
+
+
+def plot_equity_curves(py_filename, output_folder, start_date, end_date, para_dict, result_df, subchart_settings, width=None):
+
+    if not width: width = 950
+
+    app = equity_curves.Plot(py_filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, subchart_settings, width)
 
     return app
 
 
-def plot_signal_analysis(filename, output_folder, start_date, end_date, para_dict, result_df, settings):
+def plot_signal_analysis(py_filename, output_folder, start_date, end_date, para_dict, result_df, settings):
 
-    app = signals.Signals(filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings)
+    app = signals.Signals(py_filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings)
 
     return app
 
@@ -148,6 +186,11 @@ def cal_performance(save_path, start_date, end_date):
 
         result_dict['total_commission'] = total_commission
 
+        if mdd_dollar == 0:
+            result_dict['net_profit_to_mdd'] = np.inf
+        else:
+            result_dict['net_profit_to_mdd'] = net_profit / mdd_dollar
+
         df3 = df[df['action'] == 'open']
         df3 = df3.set_index('date')
         current_year = datetime.datetime.now().year
