@@ -121,6 +121,18 @@ class Components:
         return checkbox_div
 
 
+    def radioitems(self, para_dict, result_df):
+        print(para_dict)
+        print(result_df)
+
+        for key, options in enumerate(para_dict):
+            print(key, options)
+
+        radioitems_div = []
+
+        return radioitems_div
+
+
     def update_performance_matrix(self, start_date,end_date,df,para_dict):
         per_col1 = []
         per_col2 = []
@@ -399,7 +411,7 @@ class Components:
         return df_chart
 
 
-    def generate_chart_2(self,df_chart,line_colour):
+    def generate_chart_2(self,df_chart,line_colour, height):
         df_signal = df_chart.copy()
         df_signal = df_signal.dropna(subset=['action'])
         df_signal = df_signal.reset_index()
@@ -490,7 +502,7 @@ class Components:
         fig_line.add_trace(go.Scatter(mode='lines', hoverinfo='skip',
                                       x=df_chart['date'], y=df_chart['bah'],
                                       line=dict(color='#00FFFF', width=1), name='BnH Equity'), )
-        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=220,
+        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=height,
                                margin=dict(l=85, r=25, t=25, b=0),
                                font={"color": "white", 'size': 9}, yaxis={'title': 'Equity'},
                                xaxis={'title': ''}
